from colorama import Fore, init
init()

ASCII_ART = f"""
{Fore.GREEN}\
____   _________    _____________ ___ 
\\   \\ /   /  _  \\  /   _____/    |   \\
 \\   Y   /  /_\\  \\ \\_____  \\|    |   /
  \\     /    |    \\/        \\    |  / 
   \\___/\\____|__  /_______  /______/
                \\/        \\/          
"""
def main():
    print(ASCII_ART)

    print(f"{Fore.LIGHTGREEN_EX}✓ successfully started!")
    print(f"{Fore.CYAN}================= {Fore.LIGHTMAGENTA_EX}Your Welcome! {Fore.CYAN}=================")
    print(f"{Fore.GREEN}NAME      : {Fore.GREEN}Ankit Chaubey")
    print(f"{Fore.GREEN}Email     : {Fore.GREEN}m.ankitchaubey@gmail.com")
    print(f"{Fore.GREEN}Telegram  : {Fore.YELLOW}@ankit_chaubey")
    print(f"{Fore.GREEN}Bot       : {Fore.CYAN}@ChaubeyBot")
    print(f"{Fore.GREEN}GitHub    : {Fore.LIGHTMAGENTA_EX}@ankit-chaubey")
    print(f"{Fore.CYAN}========================================================")

    print(f"{Fore.LIGHTCYAN_EX}To enable the advanced dev mode, type {Fore.YELLOW}Developer secret KEY{Fore.LIGHTCYAN_EX}.\n")

    print(f"{Fore.LIGHTMAGENTA_EX}📌 Developed by Ankit Chaubey")
    print(f"{Fore.LIGHTWHITE_EX}Release Date: {Fore.LIGHTWHITE_EX}12 January 2025")
    print(f"{Fore.LIGHTWHITE_EX}PYPI Version: (V0.0.2) {Fore.LIGHTWHITE_EX}2 February 2025")
    print(f"{Fore.LIGHTWHITE_EX}API Version: (V2.4) {Fore.LIGHTWHITE_EX} February 2025\n")

    print(f"{Fore.LIGHTYELLOW_EX}⚠️ This bot is provided strictly for private use.")
    print(f"{Fore.LIGHTRED_EX}❗ Redistribution, publication, or commercial sale is strictly prohibited.")
    print(f"{Fore.LIGHTCYAN_EX}Before using, ensure you have the necessary rights to use this bot.\n")

    print(f"{Fore.LIGHTWHITE_EX}🔗 Licensed under the Private Use License.")
    print(f"{Fore.LIGHTCYAN_EX}For more details, visit: {Fore.LIGHTBLUE_EX}https://github.com/ankit-chaubey\n")

    print(f"{Fore.LIGHTGREEN_EX}Thank You, Have a nice day!")

if __name__ == "__main__":
    main()
